@@ -1,4 +1,3 @@
-
 from logging import Logger
 from logging import getLogger
 
@@ -7,7 +6,6 @@ from wx import WHITE_BRUSH
 from miniogl.Shape import Shape
 
 from pyutmodel.PyutLink import PyutLink
-
 from ogl.OglClass import OglClass
 from ogl.OglLink import OglLink
 
@@ -18,15 +16,17 @@ class OglInheritance(OglLink):
     This class provide the methods for drawing an inheritance link between
     two classes of a UML diagram. Add labels to an OglLink.
     """
-    def __init__(self, srcShape: OglClass, pyutLink: PyutLink, dstShape: OglClass):
+    def __init__(self, srcShape: OglClass, pyutLink: PyutLink, dstShape: OglClass, srcPos=None, dstPos=None):
         """
 
         Args:
             srcShape: Source shape
             pyutLink: Conceptual links associated with the graphical links.
             dstShape: Destination shape
+            srcPos:   Position of source      Override location of input source
+            dstPos:   Position of destination Override location of input destination
         """
-        super().__init__(srcShape, pyutLink, dstShape)
+        super().__init__(srcShape, pyutLink, dstShape, srcPos=srcPos, dstPos=dstPos)
 
         self.logger: Logger = getLogger(__name__)
         # Arrow must be white inside
